
# Aquire the mmtravis package (It may complain about some dependencies, just install them yourself)
install.packages("remotes")
remotes::install_github("TYMichaelsen/mmtravis")
library(mmtravis)
library(tidyverse)
library(magrittr)

# Load the data.
mmt <- readRDS("mt_example.rds")

# Retain genes with > 1000 reads (just for speed plotting heatmap)
# Also, convert counts to transcripts per milion (i.e. relative abundance).
mmt_sub <- mt_subset(mmt,minreads = 50,normalise = "TPM")

# Compute phi and correlation.
mmt_phi <- mt_phi(mmt_sub)
mmt_cor <- mmt_sub$mtdata %>%
  column_to_rownames("GeneID") %>%
  t() %>%
  cor()

# Convert to distance matrices.
phi_dist <- as.dist(mmt_phi)
cor_dist <- as.dist(1 - abs(mmt_cor))

# Hierarchical clustering.
phi_clst <- hclust(phi_dist)
cor_clst <- hclust(cor_dist)

# Plot the clustered heatmaps.
png(filename = "figure_3.png",width = 7,height = 4,units = "in",res = 700)

par(mfrow = c(1,2),mar = c(1,1,1,1))
image(
  mmt_phi[phi_clst$order,phi_clst$order],
  breaks    = quantile(mmt_phi,seq(0,1,0.1)),
  col       = (heat.colors(10)),
  useRaster = TRUE,
  yaxt = "n",
  xaxt = "n",
  asp  = 1, 
  bty  = "n",main = expression(phi~statistic))

image(
  mmt_cor[cor_clst$order,cor_clst$order],
  breaks    = quantile(mmt_cor,seq(0,1,0.1)),
  col       = (heat.colors(10)),
  useRaster = TRUE,
  yaxt = "n",
  xaxt = "n",
  asp  = 1, 
  bty  = "n",main = expression(Correlation~rho))

dev.off()